package vsp.readConfig;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import vsp.config.Config;
import vsp.config.ConfigExp;
import vsp.config.ConfigGauss;

/**
 * Abstract class for reading config file
 * 
 * @author Jan Tichava
 *
 */
public abstract class ReadConfig {

	/**
	 * Reader for config file
	 */
	private BufferedReader bufferedReader;

	/**
	 * Creates new reader and opens file
	 * 
	 * @param fileName
	 * @throws FileNotFoundException 
	 */
	public ReadConfig(String fileName) throws FileNotFoundException {
		bufferedReader =  new BufferedReader(new FileReader(fileName));		
	}
	
	/**
	 * Reads next line from config file, which is not empty and not a comment
	 * @return
	 * @throws IOException
	 */
	protected String readLine() throws IOException {
		String line = null;
		
		while (( line = bufferedReader.readLine()) != null) {
			if ((line.trim().length() < 1) || (line.charAt(0) == '#')) {
				continue;
			}

			return line;
		}
		
		return line;
	}
	
	/**
	 * Read head from config file for exp.
	 * @param config
	 * @return
	 * @throws NumberFormatException
	 * @throws IOException
	 */
	protected ConfigExp readHead(ConfigExp config) throws NumberFormatException, IOException {
		return (ConfigExp) readHead((Config) config);
	}
	
	/**
	 * Read head from config file for Gauss.
	 * @param config
	 * @return
	 * @throws NumberFormatException
	 * @throws IOException
	 */
	protected ConfigGauss readHead(ConfigGauss config) throws NumberFormatException, IOException {
		return (ConfigGauss) readHead((Config) config);
	}

	/**
	 * Read head from file
	 * @param config
	 * @return
	 * @throws NumberFormatException
	 * @throws IOException
	 */
	private Config readHead(Config config) throws NumberFormatException, IOException {
		config.setSteps(Integer.valueOf(readLine()));
		config.setScanTime(Long.valueOf(readLine()));
		
		config.setP1(Double.valueOf(readLine()));
		config.setP2(Double.valueOf(readLine()));
		config.setP3(Double.valueOf(readLine()));
		
		return config;
	}
	
	/**
	 * Read config file
	 * @return
	 * @throws NumberFormatException
	 * @throws IOException
	 */
	public abstract Config read() throws NumberFormatException, IOException;
	
	/**
	 * Close file, when disposing object
	 */
	protected void finalize() throws Throwable {
		bufferedReader.close();
		super.finalize();
	}
}
