package vsp.config;

/**
 * 
 * Implementation for Gauss.
 * 
 * @author Jan Tichava
 *
 */
public class ConfigGauss implements Config {

	/**
	 * &mu; for electronics input - default value
	 */
	private double miElectronics = 1;
	/**
	 * &sigma; for electronics input - default value
	 */
    private double sigmaElectronics = 0.7;
	/**
	 * &mu; for paper input - default value
	 */
    private double miPaper = 0.8;
	/**
	 * &sigma; for paper input - default value
	 */
    private double sigmaPaper = 0.7;
    
    /**
	 * Probability p1 - default value
	 */
	private double p1 = 0.6;
	/**
	 * Probability p2 - default value
	 */
	private double p2 = 0.9;
	/**
	 * Probability p3 - default value
	 */
	private double p3 = 0.95;
    
	/**
	 * &mu; for server 1 - default value
	 */
    private double mi1 = 0.5;
    /**
	 * &sigma; for server 1 - default value
	 */
    private double deviation1 = 0.7;
	/**
	 * &mu; for server 2 - default value
	 */
    private double mi2 = 0.7;
    /**
	 * &sigma; for server 2 - default value
	 */
    private double deviation2 = 0.7;
	/**
	 * &mu; for server 3 - default value
	 */
    private double mi3 = 0.3;
    /**
	 * &sigma; for server 3 - default value
	 */
    private double deviation3 = 0.7;
	/**
	 * &mu; for server 4 - default value
	 */
    private double mi4 = 0.4;
    /**
	 * &sigma; for server 4 - default value
	 */
    private double deviation4 = 0.7;
	
    /**
	 * Number of steps  - default value
	 */
    private int steps = 10000;
    /**
	 * Statistics scanning time  - default value
	 */
	private long scanTime = 10;
	
	
	/**
	 * Creates new configuration
	 * 
	 * @param miElectronics
	 * @param sigmaElectronics
	 * @param miPaper
	 * @param sigmaPaper
	 * @param p1
	 * @param p2
	 * @param p3
	 * @param mi1
	 * @param deviation1
	 * @param mi2
	 * @param deviation2
	 * @param mi3
	 * @param deviation3
	 * @param mi4
	 * @param deviation4
	 * @param steps
	 * @param scanTime
	 */
	public ConfigGauss(double miElectronics, double sigmaElectronics, double miPaper, double sigmaPaper, double p1, double p2, double p3, double mi1, double deviation1,
			double mi2, double deviation2, double mi3, double deviation3, double mi4, double deviation4, int steps, long scanTime) {
		this.miElectronics = miElectronics;
		this.sigmaElectronics = sigmaElectronics;
		this.miPaper = miPaper;
		this.sigmaPaper = sigmaPaper;
		this.p1 = p1;
		this.p2 = p2;
		this.p3 = p3;
		this.mi1 = mi1;
		this.deviation1 = deviation1;
		this.mi2 = mi2;
		this.deviation2 = deviation2;
		this.mi3 = mi3;
		this.deviation3 = deviation3;
		this.mi4 = mi4;
		this.deviation4 = deviation4;
		this.steps = steps;
		this.scanTime = scanTime;
	}

	/**
	 * Creates new configuration with default values
	 */
	public ConfigGauss() {
		
	}
	
	/**
	 * Creates new configuration with default values, except steps
	 * @param steps
	 */
	public ConfigGauss(int steps) {
		this.steps = steps;
	}
	
	/**
	 * Creates new configuration with default values, except deviation
	 * @param deviation
	 */
	public ConfigGauss(double deviation) {
		this.deviation1 = deviation;
		this.deviation2 = deviation;
		this.deviation3 = deviation;
		this.deviation4 = deviation;
	}

	/**
	 * Creates new configuration with default values, except deviation and steps
	 * @param deviation
	 * @param steps
	 */
	public ConfigGauss(double deviation, int steps) {
		this.deviation1 = deviation;
		this.deviation2 = deviation;
		this.deviation3 = deviation;
		this.deviation4 = deviation;
		this.steps = steps;
	}

	
	/**
	 * @return the miElectronics
	 */
	public double getMiElectronics() {
		return miElectronics;
	}


	/**
	 * @return the sigmaElectronics
	 */
	public double getSigmaElectronics() {
		return sigmaElectronics;
	}


	/**
	 * @return the miPaper
	 */
	public double getMiPaper() {
		return miPaper;
	}


	/**
	 * @return the sigmaPaper
	 */
	public double getSigmaPaper() {
		return sigmaPaper;
	}


	/**
	 * @return the p1
	 */
	public double getP1() {
		return p1;
	}


	/**
	 * @return the p2
	 */
	public double getP2() {
		return p2;
	}


	/**
	 * @return the p3
	 */
	public double getP3() {
		return p3;
	}


	/**
	 * @return the mi1
	 */
	public double getMi1() {
		return mi1;
	}


	/**
	 * @return the deviation1
	 */
	public double getDeviation1() {
		return deviation1;
	}


	/**
	 * @return the mi2
	 */
	public double getMi2() {
		return mi2;
	}


	/**
	 * @return the deviation2
	 */
	public double getDeviation2() {
		return deviation2;
	}


	/**
	 * @return the mi3
	 */
	public double getMi3() {
		return mi3;
	}


	/**
	 * @return the deviation3
	 */
	public double getDeviation3() {
		return deviation3;
	}


	/**
	 * @return the mi4
	 */
	public double getMi4() {
		return mi4;
	}


	/**
	 * @return the deviation4
	 */
	public double getDeviation4() {
		return deviation4;
	}


	/**
	 * @return the steps
	 */
	public int getSteps() {
		return steps;
	}


	/**
	 * @return the scanTime
	 */
	public long getScanTime() {
		return scanTime;
	}

	/**
	 * @param miElectronics the miElectronics to set
	 */
	public void setMiElectronics(double miElectronics) {
		this.miElectronics = miElectronics;
	}

	/**
	 * @param sigmaElectronics the sigmaElectronics to set
	 */
	public void setSigmaElectronics(double sigmaElectronics) {
		this.sigmaElectronics = sigmaElectronics;
	}

	/**
	 * @param miPaper the miPaper to set
	 */
	public void setMiPaper(double miPaper) {
		this.miPaper = miPaper;
	}

	/**
	 * @param sigmaPaper the sigmaPaper to set
	 */
	public void setSigmaPaper(double sigmaPaper) {
		this.sigmaPaper = sigmaPaper;
	}

	/**
	 * @param p1 the p1 to set
	 */
	public void setP1(double p1) {
		this.p1 = p1;
	}

	/**
	 * @param p2 the p2 to set
	 */
	public void setP2(double p2) {
		this.p2 = p2;
	}

	/**
	 * @param p3 the p3 to set
	 */
	public void setP3(double p3) {
		this.p3 = p3;
	}

	/**
	 * @param mi1 the mi1 to set
	 */
	public void setMi1(double mi1) {
		this.mi1 = mi1;
	}

	/**
	 * @param deviation1 the deviation1 to set
	 */
	public void setDeviation1(double deviation1) {
		this.deviation1 = deviation1;
	}

	/**
	 * @param mi2 the mi2 to set
	 */
	public void setMi2(double mi2) {
		this.mi2 = mi2;
	}

	/**
	 * @param deviation2 the deviation2 to set
	 */
	public void setDeviation2(double deviation2) {
		this.deviation2 = deviation2;
	}

	/**
	 * @param mi3 the mi3 to set
	 */
	public void setMi3(double mi3) {
		this.mi3 = mi3;
	}

	/**
	 * @param deviation3 the deviation3 to set
	 */
	public void setDeviation3(double deviation3) {
		this.deviation3 = deviation3;
	}

	/**
	 * @param mi4 the mi4 to set
	 */
	public void setMi4(double mi4) {
		this.mi4 = mi4;
	}

	/**
	 * @param deviation4 the deviation4 to set
	 */
	public void setDeviation4(double deviation4) {
		this.deviation4 = deviation4;
	}

	/**
	 * @param steps the steps to set
	 */
	public void setSteps(int steps) {
		this.steps = steps;
	}

	/**
	 * @param scanTime the scanTime to set
	 */
	public void setScanTime(long scanTime) {
		this.scanTime = scanTime;
	}
	
	
	
	
}
